@@ -46,6 +46,7 @@ type MockToken struct {
 
 type MockRoleToken struct {
 	mock.Mock
+	isPrefetcherStarted bool
 }
 
 func (m *MockTokenBuilder) SetExpiration(_ time.Duration) {
@@ -71,6 +72,18 @@ func (m *MockRoleToken) RoleTokenValue() (string, error) {
 	return result.Get(0).(string), result.Error(1)
 }
 
+func (m *MockRoleToken) StartPrefetcher() error {
+	m.isPrefetcherStarted = true
+	result := m.Called()
+	return result.Error(0)
+}
+
+func (m *MockRoleToken) StopPrefetcher() error {
+	m.isPrefetcherStarted = false
+	result := m.Called()
+	return result.Error(0)
+}
+
 func MockZmsNewTokenBuilder(domain, name string, privateKeyPEM []byte, keyVersion string) (zms.TokenBuilder, error) {
 	// assertion
 	key, err := os.ReadFile(clientKeyPath)
@@ -105,7 +118,13 @@ func MockZtsNewRoleToken(tok zms.Token, domain string, opts zts.RoleTokenOptions
 	}
 
 	mockRoleToken := new(MockRoleToken)
-	mockRoleToken.On("RoleTokenValue").Return("mockRoleToken", nil)
+	if opts.ProxyURL == "" {
+		mockRoleToken.On("RoleTokenValue").Return("mockRoleToken", nil)
+	} else {
+		mockRoleToken.On("RoleTokenValue").Return("mockRoleToken-"+opts.ProxyURL, nil)
+	}
+	mockRoleToken.On("StartPrefetcher").Return(nil)
+	mockRoleToken.On("StopPrefetcher").Return(nil)
 	return mockRoleToken
 }
 
@@ -121,7 +140,13 @@ func MockZtsNewRoleTokenFromCert(certFile, keyFile, domain string, opts zts.Role
 	}
 
 	mockRoleToken := new(MockRoleToken)
-	mockRoleToken.On("RoleTokenValue").Return("mockRoleTokenFromCert", nil)
+	if opts.ProxyURL == "" {
+		mockRoleToken.On("RoleTokenValue").Return("mockRoleTokenFromCert", nil)
+	} else {
+		mockRoleToken.On("RoleTokenValue").Return("mockRoleTokenFromCert-"+opts.ProxyURL, nil)
+	}
+	mockRoleToken.On("StartPrefetcher").Return(nil)
+	mockRoleToken.On("StopPrefetcher").Return(nil)
 	return mockRoleToken
 }
 
@@ -137,7 +162,8 @@ func TestAthenzAuth(t *testing.T) {
 		"",                      // caCert
 		"",                      // principalHeader
 		"",                      // roleHeader
-		"http://localhost:9999") // ztsURL
+		"http://localhost:9999", // ztsURL
+		"")                      // ztsProxyURL
 
 	// inject mock function
 	athenz := provider.(*athenzAuthProvider)
@@ -146,10 +172,48 @@ func TestAthenzAuth(t *testing.T) {
 
 	err := athenz.Init()
 	assert.NoError(t, err)
+	assert.True(t, athenz.roleToken.(*MockRoleToken).isPrefetcherStarted)
 
 	data, err := athenz.GetData()
 	assert.Equal(t, []byte("mockRoleToken"), data)
 	assert.NoError(t, err)
+
+	err = athenz.Close()
+	assert.NoError(t, err)
+	assert.False(t, athenz.roleToken.(*MockRoleToken).isPrefetcherStarted)
+}
+
+func TestAthenzAuthWithProxy(t *testing.T) {
+	privateKey := "file://" + clientKeyPath
+	provider := NewAuthenticationAthenz(
+		"pulsar.test.provider",  // providerDomain
+		"pulsar.test.tenant",    // tenantDomain
+		"service",               // tenantService
+		privateKey,              // privateKey
+		"",                      // keyID
+		"",                      // x509CertChain
+		"",                      // caCert
+		"",                      // principalHeader
+		"",                      // roleHeader
+		"http://localhost:9999", // ztsURL
+		"http://localhost:8080") // ztsProxyURL
+
+	// inject mock function
+	athenz := provider.(*athenzAuthProvider)
+	athenz.zmsNewTokenBuilder = MockZmsNewTokenBuilder
+	athenz.ztsNewRoleToken = MockZtsNewRoleToken
+
+	err := athenz.Init()
+	assert.NoError(t, err)
+	assert.True(t, athenz.roleToken.(*MockRoleToken).isPrefetcherStarted)
+
+	data, err := athenz.GetData()
+	assert.Equal(t, []byte("mockRoleToken-http://localhost:8080"), data)
+	assert.NoError(t, err)
+
+	err = athenz.Close()
+	assert.NoError(t, err)
+	assert.False(t, athenz.roleToken.(*MockRoleToken).isPrefetcherStarted)
 }
 
 func TestCopperArgos(t *testing.T) {
@@ -167,7 +231,8 @@ func TestCopperArgos(t *testing.T) {
 		caCert,                  // caCert
 		"",                      // principalHeader
 		"",                      // roleHeader
-		"http://localhost:9999") // ztsURL
+		"http://localhost:9999", // ztsURL
+		"")                      // ztsProxyURL
 
 	// inject mock function
 	athenz := provider.(*athenzAuthProvider)
@@ -175,10 +240,50 @@ func TestCopperArgos(t *testing.T) {
 
 	err := athenz.Init()
 	assert.NoError(t, err)
+	assert.True(t, athenz.roleToken.(*MockRoleToken).isPrefetcherStarted)
 
 	data, err := athenz.GetData()
 	assert.Equal(t, []byte("mockRoleTokenFromCert"), data)
 	assert.NoError(t, err)
+
+	err = athenz.Close()
+	assert.NoError(t, err)
+	assert.False(t, athenz.roleToken.(*MockRoleToken).isPrefetcherStarted)
+}
+
+func TestCopperArgosWithProxy(t *testing.T) {
+	privateKey := "file://" + clientKeyPath
+	x509CertChain := "file://" + clientCertPath
+	caCert := "file://" + caCertPath
+
+	provider := NewAuthenticationAthenz(
+		"pulsar.test.provider",  // providerDomain
+		"",                      // tenantDomain
+		"",                      // tenantService
+		privateKey,              // privateKey
+		"",                      // keyID
+		x509CertChain,           // x509CertChain
+		caCert,                  // caCert
+		"",                      // principalHeader
+		"",                      // roleHeader
+		"http://localhost:9999", // ztsURL
+		"http://localhost:8080") // ztsProxyURL
+
+	// inject mock function
+	athenz := provider.(*athenzAuthProvider)
+	athenz.ztsNewRoleTokenFromCert = MockZtsNewRoleTokenFromCert
+
+	err := athenz.Init()
+	assert.NoError(t, err)
+	assert.True(t, athenz.roleToken.(*MockRoleToken).isPrefetcherStarted)
+
+	data, err := athenz.GetData()
+	assert.Equal(t, []byte("mockRoleTokenFromCert-http://localhost:8080"), data)
+	assert.NoError(t, err)
+
+	err = athenz.Close()
+	assert.NoError(t, err)
+	assert.False(t, athenz.roleToken.(*MockRoleToken).isPrefetcherStarted)
 }
 
 func TestIllegalParams(t *testing.T) {
@@ -195,7 +300,8 @@ func TestIllegalParams(t *testing.T) {
 		"",                      // caCert
 		"",                      // principalHeader
 		"",                      // roleHeader
-		"http://localhost:9999") // ztsURL
+		"http://localhost:9999", // ztsURL
+		"")                      // ztsProxyURL
 	athenz := provider.(*athenzAuthProvider)
 
 	err := athenz.Init()
@@ -212,7 +318,8 @@ func TestIllegalParams(t *testing.T) {
 		"",                      // caCert
 		"",                      // principalHeader
 		"",                      // roleHeader
-		"http://localhost:9999") // ztsURL
+		"http://localhost:9999", // ztsURL
+		"")                      // ztsProxyURL
 	athenz = provider.(*athenzAuthProvider)
 
 	err = athenz.Init()
@@ -229,7 +336,8 @@ func TestIllegalParams(t *testing.T) {
 		"",                      // caCert
 		"",                      // principalHeader
 		"",                      // roleHeader
-		"http://localhost:9999") // ztsURL
+		"http://localhost:9999", // ztsURL
+		"")                      // ztsProxyURL
 	athenz = provider.(*athenzAuthProvider)
 
 	err = athenz.Init()
@@ -246,7 +354,8 @@ func TestIllegalParams(t *testing.T) {
 		"",                      // caCert
 		"",                      // principalHeader
 		"",                      // roleHeader
-		"http://localhost:9999") // ztsURL
+		"http://localhost:9999", // ztsURL
+		"")                      // ztsProxyURL
 	athenz = provider.(*athenzAuthProvider)
 
 	err = athenz.Init()
