@@ -58,6 +58,26 @@ func (te *MockTokenExchanger) ExchangeDeviceCode(_ context.Context,
 	return te.ReturnsTokens, te.ReturnsError
 }
 
+type MockGrantProvider struct {
+	keyFile *KeyFile
+}
+
+func (mgp *MockGrantProvider) GetGrant(audience string, opts *ClientCredentialsFlowOptions) (
+	*AuthorizationGrant, error) {
+	scopes := []string{mgp.keyFile.Scope}
+	if opts != nil && len(opts.AdditionalScopes) > 0 {
+		scopes = append(scopes, opts.AdditionalScopes...)
+	}
+	return &AuthorizationGrant{
+		Type:              GrantTypeClientCredentials,
+		Audience:          audience,
+		ClientID:          mgp.keyFile.ClientID,
+		ClientCredentials: mgp.keyFile,
+		TokenEndpoint:     oidcEndpoints.TokenEndpoint,
+		Scopes:            scopes,
+	}, nil
+}
+
 var oidcEndpoints = OIDCWellKnownEndpoints{
 	AuthorizationEndpoint:       "http://issuer/auth/authorize",
 	TokenEndpoint:               "http://issuer/auth/token",
