@@ -118,6 +118,12 @@ func newConsumer(client *client, options ConsumerOptions) (Consumer, error) {
 		options.NackBackoffPolicy = new(defaultNackBackoffPolicy)
 	}
 
+	if options.NackPrecisionBit == nil {
+		options.NackPrecisionBit = ptr(defaultNackPrecisionBit)
+	} else if *options.NackPrecisionBit < 0 {
+		return nil, newError(InvalidConfiguration, "NackPrecisionBit cannot be negative")
+	}
+
 	// did the user pass in a message channel?
 	messageCh := options.MessageChannel
 	if options.MessageChannel == nil {
@@ -452,6 +458,7 @@ func newPartitionConsumerOpts(topic, consumerName string, idx int, options Consu
 		receiverQueueSize:           options.ReceiverQueueSize,
 		nackRedeliveryDelay:         nackRedeliveryDelay,
 		nackBackoffPolicy:           options.NackBackoffPolicy,
+		nackPrecisionBit:            options.NackPrecisionBit,
 		metadata:                    options.Properties,
 		subProperties:               options.SubscriptionProperties,
 		replicateSubscriptionState:  options.ReplicateSubscriptionState,
