@@ -24,8 +24,12 @@ import (
 // BlockingQueue is a interface of block queue
 type BlockingQueue interface {
 	// Put enqueue one item, block if the queue is full
+	// This is currently used for the internal testing
 	Put(item interface{})
 
+	// PutUnsafe enqueue one item without locking the queue, block if the queue is full
+	PutUnsafe(item interface{})
+
 	// Take dequeue one item, block until it's available
 	Take() interface{}
 
@@ -46,6 +50,17 @@ type BlockingQueue interface {
 
 	// ReadableSlice returns a new view of the readable items in the queue
 	ReadableSlice() []interface{}
+
+	// IterateUnsafe iterates the items in the queue without blocking the queue
+	IterateUnsafe(func(item interface{}))
+
+	// Lock locks the queue for manual control
+	// Users must call Unlock() after finishing their operations
+	Lock()
+
+	// Unlock unlocks the queue
+	// Must be called after Lock() to release the lock
+	Unlock()
 }
 
 type blockingQueue struct {
@@ -60,6 +75,17 @@ type blockingQueue struct {
 	isNotFull  *sync.Cond
 }
 
+func (bq *blockingQueue) IterateUnsafe(f func(item interface{})) {
+	readIdx := bq.headIdx
+	for i := 0; i < bq.size; i++ {
+		f(bq.items[readIdx])
+		readIdx++
+		if readIdx == bq.maxSize {
+			readIdx = 0
+		}
+	}
+}
+
 // NewBlockingQueue init block queue and returns a BlockingQueue
 func NewBlockingQueue(maxSize int) BlockingQueue {
 	bq := &blockingQueue{
@@ -76,9 +102,12 @@ func NewBlockingQueue(maxSize int) BlockingQueue {
 }
 
 func (bq *blockingQueue) Put(item interface{}) {
-	bq.mutex.Lock()
-	defer bq.mutex.Unlock()
+	bq.Lock()
+	defer bq.Unlock()
+	bq.PutUnsafe(item)
+}
 
+func (bq *blockingQueue) PutUnsafe(item interface{}) {
 	for bq.size == bq.maxSize {
 		bq.isNotFull.Wait()
 	}
@@ -192,3 +221,11 @@ func (bq *blockingQueue) ReadableSlice() []interface{} {
 
 	return res
 }
+
+func (bq *blockingQueue) Lock() {
+	bq.mutex.Lock()
+}
+
+func (bq *blockingQueue) Unlock() {
+	bq.mutex.Unlock()
+}
