@@ -385,6 +385,7 @@ func (c *connection) failLeftRequestsWhenClose() {
 		// if other requests come in after the nil message
 		// then the RPC client will time out
 		ch <- nil
+		c.writeRequestsCh <- nil
 	}()
 	for req := range ch {
 		if nil == req {
@@ -392,6 +393,12 @@ func (c *connection) failLeftRequestsWhenClose() {
 		}
 		c.internalSendRequest(req)
 	}
+	for req := range c.writeRequestsCh {
+		if nil == req {
+			break
+		}
+		req.data.Release()
+	}
 }
 
 func (c *connection) run() {
@@ -432,6 +439,7 @@ func (c *connection) run() {
 				return
 			}
 			c.internalWriteData(req.ctx, req.data)
+			req.data.Release()
 
 		case <-pingSendTicker.C:
 			c.sendPing()
@@ -457,13 +465,23 @@ func (c *connection) runPingCheck(pingCheckTicker *time.Ticker) {
 }
 
 func (c *connection) WriteData(ctx context.Context, data Buffer) {
+	writeToQueue := false
+	defer func() {
+		if !writeToQueue {
+			data.Release()
+		}
+	}()
 	select {
 	case c.writeRequestsCh <- &dataRequest{ctx: ctx, data: data}:
 		// Channel is not full
+		writeToQueue = true
 		return
 	case <-ctx.Done():
 		c.log.Debug("Write data context cancelled")
 		return
+	case <-c.closeCh:
+		c.log.Debug("Write data connection closed")
+		return
 	default:
 		// Channel full, fallback to probe if connection is closed
 	}
@@ -472,10 +490,14 @@ func (c *connection) WriteData(ctx context.Context, data Buffer) {
 		select {
 		case c.writeRequestsCh <- &dataRequest{ctx: ctx, data: data}:
 			// Successfully wrote on the channel
+			writeToQueue = true
 			return
 		case <-ctx.Done():
 			c.log.Debug("Write data context cancelled")
 			return
+		case <-c.closeCh:
+			c.log.Debug("Write data connection closed")
+			return
 		case <-time.After(100 * time.Millisecond):
 			// The channel is either:
 			// 1. blocked, in which case we need to wait until we have space
@@ -497,6 +519,8 @@ func (c *connection) internalWriteData(ctx context.Context, data Buffer) {
 	select {
 	case <-ctx.Done():
 		return
+	case <-c.closeCh:
+		return
 	default:
 		if _, err := c.cnx.Write(data.ReadableSlice()); err != nil {
 			c.log.WithError(err).Warn("Failed to write on connection")
