@@ -25,7 +25,6 @@ import (
 	"testing"
 
 	"github.com/apache/pulsar-client-go/oauth2"
-	"github.com/apache/pulsar-client-go/oauth2/store"
 	"github.com/pkg/errors"
 	"github.com/stretchr/testify/assert"
 )
@@ -99,37 +98,20 @@ func TestOauth2(t *testing.T) {
 		Audience:       server.URL,
 	}
 
-	memoryStore := store.NewMemoryStore()
-	err = saveGrant(memoryStore, kf, issuer.Audience)
+	auth, err := NewAuthenticationOAuth2WithFlow(issuer, oauth2.ClientCredentialsFlowOptions{
+		KeyFile: kf,
+	})
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	auth, err := NewAuthenticationOAuth2(issuer, memoryStore)
-	if err != nil {
-		t.Fatal(err)
+	provider, ok := auth.(*OAuth2Provider)
+	if !ok {
+		t.Fatal("unexpected provider type")
 	}
-
-	token, err := auth.source.Token()
+	token, err := provider.source.Token()
 	if err != nil {
 		t.Fatal(err)
 	}
 	assert.Equal(t, "token-content", token.AccessToken)
 }
-
-func saveGrant(store store.Store, keyFile, audience string) error {
-	flow, err := oauth2.NewDefaultClientCredentialsFlow(oauth2.ClientCredentialsFlowOptions{
-		KeyFile:          keyFile,
-		AdditionalScopes: nil,
-	})
-	if err != nil {
-		return err
-	}
-
-	grant, err := flow.Authorize(audience)
-	if err != nil {
-		return err
-	}
-
-	return store.SaveGrant(audience, *grant)
-}
