@@ -88,16 +88,18 @@ type Namespaces interface {
 	// SetNamespaceMessageTTLWithContext sets the messages Time to Live for all the topics within a namespace
 	SetNamespaceMessageTTLWithContext(ctx context.Context, namespace string, ttlInSeconds int) error
 
-	// GetNamespaceMessageTTL returns the message TTL for a namespace
+	// GetNamespaceMessageTTL returns the message TTL for a namespace. Returns -1 if not set
 	GetNamespaceMessageTTL(namespace string) (int, error)
 
-	// GetNamespaceMessageTTLWithContext returns the message TTL for a namespace
+	// GetNamespaceMessageTTLWithContext returns the message TTL for a namespace. Returns -1 if not set
 	GetNamespaceMessageTTLWithContext(ctx context.Context, namespace string) (int, error)
 
-	// GetRetention returns the retention configuration for a namespace
+	// GetRetention returns the retention configuration for a namespace.
+	// Returns nil if the retention policy is not configured at the namespace level.
 	GetRetention(namespace string) (*utils.RetentionPolicies, error)
 
-	// GetRetentionWithContext returns the retention configuration for a namespace
+	// GetRetentionWithContext returns the retention configuration for a namespace.
+	// Returns nil if the retention policy is not configured at the namespace level.
 	GetRetentionWithContext(ctx context.Context, namespace string) (*utils.RetentionPolicies, error)
 
 	// SetRetention sets the retention configuration for all the topics on a namespace
@@ -132,10 +134,12 @@ type Namespaces interface {
 	// RemoveBacklogQuotaWithContext removes a backlog quota policy from a namespace
 	RemoveBacklogQuotaWithContext(ctx context.Context, namespace string) error
 
-	// GetTopicAutoCreation returns the topic auto-creation config for a namespace
+	// GetTopicAutoCreation returns the topic auto-creation config for a namespace.
+	// Returns nil if the topic auto-creation config is not configured at the namespace level.
 	GetTopicAutoCreation(namespace utils.NameSpaceName) (*utils.TopicAutoCreationConfig, error)
 
-	// GetTopicAutoCreationWithContext returns the topic auto-creation config for a namespace
+	// GetTopicAutoCreationWithContext returns the topic auto-creation config for a namespace.
+	// Returns nil if the topic auto-creation config is not configured at the namespace level.
 	GetTopicAutoCreationWithContext(
 		ctx context.Context,
 		namespace utils.NameSpaceName,
@@ -226,10 +230,11 @@ type Namespaces interface {
 	// SetOffloadDeleteLagWithContext sets the offload deletion lag for a namespace
 	SetOffloadDeleteLagWithContext(ctx context.Context, namespace utils.NameSpaceName, timeMs int64) error
 
-	// GetOffloadDeleteLag returns the offload deletion lag for a namespace, in milliseconds
+	// GetOffloadDeleteLag returns the offload deletion lag for a namespace, in milliseconds. Returns -1 if not set
 	GetOffloadDeleteLag(namespace utils.NameSpaceName) (int64, error)
 
-	// GetOffloadDeleteLagWithContext returns the offload deletion lag for a namespace, in milliseconds
+	// GetOffloadDeleteLagWithContext returns the offload deletion lag for a namespace, in milliseconds.
+	// Returns -1 if not set
 	GetOffloadDeleteLagWithContext(ctx context.Context, namespace utils.NameSpaceName) (int64, error)
 
 	// SetOffloadThreshold sets the offloadThreshold for a namespace
@@ -238,10 +243,10 @@ type Namespaces interface {
 	// SetOffloadThresholdWithContext sets the offloadThreshold for a namespace
 	SetOffloadThresholdWithContext(ctx context.Context, namespace utils.NameSpaceName, threshold int64) error
 
-	// GetOffloadThreshold returns the offloadThreshold for a namespace
+	// GetOffloadThreshold returns the offloadThreshold for a namespace. Returns -1 if not set
 	GetOffloadThreshold(namespace utils.NameSpaceName) (int64, error)
 
-	// GetOffloadThresholdWithContext returns the offloadThreshold for a namespace
+	// GetOffloadThresholdWithContext returns the offloadThreshold for a namespace. Returns -1 if not set
 	GetOffloadThresholdWithContext(ctx context.Context, namespace utils.NameSpaceName) (int64, error)
 
 	// SetOffloadThresholdInSeconds sets the offloadThresholdInSeconds for a namespace
@@ -250,10 +255,10 @@ type Namespaces interface {
 	// SetOffloadThresholdInSecondsWithContext sets the offloadThresholdInSeconds for a namespace
 	SetOffloadThresholdInSecondsWithContext(ctx context.Context, namespace utils.NameSpaceName, threshold int64) error
 
-	// GetOffloadThresholdInSeconds returns the offloadThresholdInSeconds for a namespace
+	// GetOffloadThresholdInSeconds returns the offloadThresholdInSeconds for a namespace. Returns -1 if not set
 	GetOffloadThresholdInSeconds(namespace utils.NameSpaceName) (int64, error)
 
-	// GetOffloadThresholdInSecondsWithContext returns the offloadThresholdInSeconds for a namespace
+	// GetOffloadThresholdInSecondsWithContext returns the offloadThresholdInSeconds for a namespace. Returns -1 if not set
 	GetOffloadThresholdInSecondsWithContext(ctx context.Context, namespace utils.NameSpaceName) (int64, error)
 
 	// SetCompactionThreshold sets the compactionThreshold for a namespace
@@ -262,10 +267,10 @@ type Namespaces interface {
 	// SetCompactionThresholdWithContext sets the compactionThreshold for a namespace
 	SetCompactionThresholdWithContext(ctx context.Context, namespace utils.NameSpaceName, threshold int64) error
 
-	// GetCompactionThreshold returns the compactionThreshold for a namespace
+	// GetCompactionThreshold returns the compactionThreshold for a namespace. Returns -1 if not set
 	GetCompactionThreshold(namespace utils.NameSpaceName) (int64, error)
 
-	// GetCompactionThresholdWithContext returns the compactionThreshold for a namespace
+	// GetCompactionThresholdWithContext returns the compactionThreshold for a namespace. Returns -1 if not set
 	GetCompactionThresholdWithContext(ctx context.Context, namespace utils.NameSpaceName) (int64, error)
 
 	// SetMaxConsumersPerSubscription sets maxConsumersPerSubscription for a namespace.
@@ -276,10 +281,11 @@ type Namespaces interface {
 	//nolint: revive // It's ok here to use a built-in function name (max)
 	SetMaxConsumersPerSubscriptionWithContext(ctx context.Context, namespace utils.NameSpaceName, max int) error
 
-	// GetMaxConsumersPerSubscription returns the maxConsumersPerSubscription for a namespace.
+	// GetMaxConsumersPerSubscription returns the maxConsumersPerSubscription for a namespace. Returns -1 if not set
 	GetMaxConsumersPerSubscription(namespace utils.NameSpaceName) (int, error)
 
 	// GetMaxConsumersPerSubscriptionWithContext returns the maxConsumersPerSubscription for a namespace.
+	// Returns -1 if not set
 	GetMaxConsumersPerSubscriptionWithContext(ctx context.Context, namespace utils.NameSpaceName) (int, error)
 
 	// SetMaxConsumersPerTopic sets maxConsumersPerTopic for a namespace.
@@ -290,10 +296,10 @@ type Namespaces interface {
 	//nolint: revive // It's ok here to use a built-in function name (max)
 	SetMaxConsumersPerTopicWithContext(ctx context.Context, namespace utils.NameSpaceName, max int) error
 
-	// GetMaxConsumersPerTopic returns the maxProducersPerTopic for a namespace.
+	// GetMaxConsumersPerTopic returns the maxProducersPerTopic for a namespace. Returns -1 if not set
 	GetMaxConsumersPerTopic(namespace utils.NameSpaceName) (int, error)
 
-	// GetMaxConsumersPerTopicWithContext returns the maxProducersPerTopic for a namespace.
+	// GetMaxConsumersPerTopicWithContext returns the maxProducersPerTopic for a namespace. Returns -1 if not set
 	GetMaxConsumersPerTopicWithContext(ctx context.Context, namespace utils.NameSpaceName) (int, error)
 
 	// SetMaxProducersPerTopic sets maxProducersPerTopic for a namespace.
@@ -304,10 +310,10 @@ type Namespaces interface {
 	//nolint: revive // It's ok here to use a built-in function name (max)
 	SetMaxProducersPerTopicWithContext(ctx context.Context, namespace utils.NameSpaceName, max int) error
 
-	// GetMaxProducersPerTopic returns the maxProducersPerTopic for a namespace.
+	// GetMaxProducersPerTopic returns the maxProducersPerTopic for a namespace. Returns -1 if not set
 	GetMaxProducersPerTopic(namespace utils.NameSpaceName) (int, error)
 
-	// GetMaxProducersPerTopicWithContext returns the maxProducersPerTopic for a namespace.
+	// GetMaxProducersPerTopicWithContext returns the maxProducersPerTopic for a namespace. Returns -1 if not set
 	GetMaxProducersPerTopicWithContext(ctx context.Context, namespace utils.NameSpaceName) (int, error)
 
 	// SetMaxTopicsPerNamespace sets maxTopicsPerNamespace for a namespace.
@@ -390,10 +396,12 @@ type Namespaces interface {
 	// SetPersistenceWithContext sets the persistence configuration for all the topics on a namespace
 	SetPersistenceWithContext(ctx context.Context, namespace string, persistence utils.PersistencePolicies) error
 
-	// GetPersistence returns the persistence configuration for a namespace
+	// GetPersistence returns the persistence configuration for a namespace.
+	// Returns nil if the persistence policy is not configured at the namespace level.
 	GetPersistence(namespace string) (*utils.PersistencePolicies, error)
 
-	// GetPersistenceWithContext returns the persistence configuration for a namespace
+	// GetPersistenceWithContext returns the persistence configuration for a namespace.
+	// Returns nil if the persistence policy is not configured at the namespace level.
 	GetPersistenceWithContext(ctx context.Context, namespace string) (*utils.PersistencePolicies, error)
 
 	// SetBookieAffinityGroup sets bookie affinity group for a namespace to isolate namespace write to bookies that are
@@ -414,10 +422,12 @@ type Namespaces interface {
 	// DeleteBookieAffinityGroupWithContext deletes bookie affinity group configured for a namespace
 	DeleteBookieAffinityGroupWithContext(ctx context.Context, namespace string) error
 
-	// GetBookieAffinityGroup returns bookie affinity group configured for a namespace
+	// GetBookieAffinityGroup returns bookie affinity group configured for a namespace.
+	// Returns nil if the bookie affinity group is not configured at the namespace level.
 	GetBookieAffinityGroup(namespace string) (*utils.BookieAffinityGroupData, error)
 
-	// GetBookieAffinityGroupWithContext returns bookie affinity group configured for a namespace
+	// GetBookieAffinityGroupWithContext returns bookie affinity group configured for a namespace.
+	// Returns nil if the bookie affinity group is not configured at the namespace level.
 	GetBookieAffinityGroupWithContext(ctx context.Context, namespace string) (*utils.BookieAffinityGroupData, error)
 
 	// Unload a namespace from the current serving broker
@@ -851,7 +861,7 @@ func (n *namespaces) GetNamespaceMessageTTL(namespace string) (int, error) {
 }
 
 func (n *namespaces) GetNamespaceMessageTTLWithContext(ctx context.Context, namespace string) (int, error) {
-	var ttl int
+	var ttl = -1
 	nsName, err := utils.GetNamespaceName(namespace)
 	if err != nil {
 		return 0, err
@@ -903,8 +913,11 @@ func (n *namespaces) GetRetentionWithContext(ctx context.Context, namespace stri
 		return nil, err
 	}
 	endpoint := n.pulsar.endpoint(n.basePath, nsName.String(), "retention")
-	err = n.pulsar.Client.GetWithContext(ctx, endpoint, &policy)
-	return &policy, err
+	body, err := n.pulsar.Client.GetBodyWithContext(ctx, endpoint, &policy)
+	if body != nil {
+		return &policy, err
+	}
+	return nil, err
 }
 
 func (n *namespaces) GetBacklogQuotaMap(namespace string) (map[utils.BacklogQuotaType]utils.BacklogQuota, error) {
@@ -968,8 +981,11 @@ func (n *namespaces) GetTopicAutoCreationWithContext(
 ) (*utils.TopicAutoCreationConfig, error) {
 	var topicAutoCreation utils.TopicAutoCreationConfig
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "autoTopicCreation")
-	err := n.pulsar.Client.GetWithContext(ctx, endpoint, &topicAutoCreation)
-	return &topicAutoCreation, err
+	body, err := n.pulsar.Client.GetBodyWithContext(ctx, endpoint, &topicAutoCreation)
+	if body != nil {
+		return &topicAutoCreation, err
+	}
+	return nil, err
 }
 
 func (n *namespaces) SetTopicAutoCreation(namespace utils.NameSpaceName, config utils.TopicAutoCreationConfig) error {
@@ -1114,7 +1130,7 @@ func (n *namespaces) GetOffloadDeleteLag(namespace utils.NameSpaceName) (int64,
 }
 
 func (n *namespaces) GetOffloadDeleteLagWithContext(ctx context.Context, namespace utils.NameSpaceName) (int64, error) {
-	var result int64
+	var result int64 = -1
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "offloadDeletionLagMs")
 	err := n.pulsar.Client.GetWithContext(ctx, endpoint, &result)
 	return result, err
@@ -1143,7 +1159,7 @@ func (n *namespaces) GetMaxConsumersPerSubscriptionWithContext(
 	ctx context.Context,
 	namespace utils.NameSpaceName,
 ) (int, error) {
-	var result int
+	var result = -1
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "maxConsumersPerSubscription")
 	err := n.pulsar.Client.GetWithContext(ctx, endpoint, &result)
 	return result, err
@@ -1167,7 +1183,7 @@ func (n *namespaces) GetOffloadThreshold(namespace utils.NameSpaceName) (int64,
 }
 
 func (n *namespaces) GetOffloadThresholdWithContext(ctx context.Context, namespace utils.NameSpaceName) (int64, error) {
-	var result int64
+	var result int64 = -1
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "offloadThreshold")
 	err := n.pulsar.Client.GetWithContext(ctx, endpoint, &result)
 	return result, err
@@ -1194,7 +1210,7 @@ func (n *namespaces) GetOffloadThresholdInSecondsWithContext(
 	ctx context.Context,
 	namespace utils.NameSpaceName,
 ) (int64, error) {
-	var result int64
+	var result int64 = -1
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "offloadThresholdInSeconds")
 	err := n.pulsar.Client.GetWithContext(ctx, endpoint, &result)
 	return result, err
@@ -1223,7 +1239,7 @@ func (n *namespaces) GetMaxConsumersPerTopicWithContext(
 	ctx context.Context,
 	namespace utils.NameSpaceName,
 ) (int, error) {
-	var result int
+	var result = -1
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "maxConsumersPerTopic")
 	err := n.pulsar.Client.GetWithContext(ctx, endpoint, &result)
 	return result, err
@@ -1250,7 +1266,7 @@ func (n *namespaces) GetCompactionThresholdWithContext(
 	ctx context.Context,
 	namespace utils.NameSpaceName,
 ) (int64, error) {
-	var result int64
+	var result int64 = -1
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "compactionThreshold")
 	err := n.pulsar.Client.GetWithContext(ctx, endpoint, &result)
 	return result, err
@@ -1279,7 +1295,7 @@ func (n *namespaces) GetMaxProducersPerTopicWithContext(
 	ctx context.Context,
 	namespace utils.NameSpaceName,
 ) (int, error) {
-	var result int
+	var result = -1
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "maxProducersPerTopic")
 	err := n.pulsar.Client.GetWithContext(ctx, endpoint, &result)
 	return result, err
@@ -1461,8 +1477,11 @@ func (n *namespaces) GetBookieAffinityGroupWithContext(
 		return nil, err
 	}
 	endpoint := n.pulsar.endpoint(n.basePath, nsName.String(), "persistence", "bookieAffinity")
-	err = n.pulsar.Client.GetWithContext(ctx, endpoint, &data)
-	return &data, err
+	body, err := n.pulsar.Client.GetBodyWithContext(ctx, endpoint, &data)
+	if body != nil {
+		return &data, err
+	}
+	return nil, err
 }
 
 func (n *namespaces) GetPersistence(namespace string) (*utils.PersistencePolicies, error) {
@@ -1479,8 +1498,11 @@ func (n *namespaces) GetPersistenceWithContext(
 		return nil, err
 	}
 	endpoint := n.pulsar.endpoint(n.basePath, nsName.String(), "persistence")
-	err = n.pulsar.Client.GetWithContext(ctx, endpoint, &persistence)
-	return &persistence, err
+	body, err := n.pulsar.Client.GetBodyWithContext(ctx, endpoint, &persistence)
+	if body != nil {
+		return &persistence, err
+	}
+	return nil, err
 }
 
 func (n *namespaces) Unload(namespace string) error {
@@ -2014,7 +2036,7 @@ func (n *namespaces) GetMaxTopicsPerNamespaceWithContext(
 	ctx context.Context,
 	namespace utils.NameSpaceName,
 ) (int, error) {
-	var result int
+	var result int // This method does not require a sentinel value of -1 since the API never returns empty
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "maxTopicsPerNamespace")
 	err := n.pulsar.Client.GetWithContext(ctx, endpoint, &result)
 	return result, err
