@@ -18,6 +18,7 @@
 package admin
 
 import (
+	"os"
 	"testing"
 	"time"
 
@@ -156,23 +157,20 @@ func TestGetTopicAutoCreation(t *testing.T) {
 	assert.Equal(t, nil, err)
 	topicAutoCreation, err := admin.Namespaces().GetTopicAutoCreation(*namespace)
 	assert.Equal(t, nil, err)
+	assert.NotNil(t, topicAutoCreation, "Expected non-nil when topic auto creation is configured")
 	expected := utils.TopicAutoCreationConfig{
 		Allow: true,
 		Type:  utils.NonPartitioned,
 	}
 	assert.Equal(t, expected, *topicAutoCreation)
 
-	// remove the topic auto creation config and get it
+	// remove the topic auto creation config and get it - should return nil
 	err = admin.Namespaces().RemoveTopicAutoCreation(*namespace)
 	assert.Equal(t, nil, err)
 
 	topicAutoCreation, err = admin.Namespaces().GetTopicAutoCreation(*namespace)
 	assert.Equal(t, nil, err)
-	expected = utils.TopicAutoCreationConfig{
-		Allow: false,
-		Type:  "",
-	}
-	assert.Equal(t, expected, *topicAutoCreation)
+	assert.Nil(t, topicAutoCreation, "Expected nil when topic auto creation is not configured")
 }
 
 func TestRevokeSubPermission(t *testing.T) {
@@ -333,7 +331,11 @@ func TestNamespaces_GetOffloadThresholdInSeconds(t *testing.T) {
 
 	namespace, _ := utils.GetNamespaceName("public/default")
 
-	// set the subscription expiration time and get it
+	// Get default (should be -1)
+	threshold, err := admin.Namespaces().GetOffloadThreshold(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, int64(-1), threshold)
+
 	err = admin.Namespaces().SetOffloadThresholdInSeconds(*namespace,
 		60)
 	assert.Equal(t, nil, err)
@@ -599,3 +601,264 @@ func TestNamespaces_GetMaxTopicsPerNamespace(t *testing.T) {
 	expected = 0
 	assert.Equal(t, expected, maxTopics)
 }
+
+func TestNamespaces_MessageTTL(t *testing.T) {
+	config := &config.Config{}
+	admin, err := New(config)
+	require.NoError(t, err)
+	require.NotNil(t, admin)
+
+	namespace, _ := utils.GetNamespaceName("public/default")
+
+	// Get default (should be -1)
+	ttl, err := admin.Namespaces().GetNamespaceMessageTTL(namespace.String())
+	assert.NoError(t, err)
+	assert.Equal(t, -1, ttl)
+
+	// Set to 0 explicitly
+	err = admin.Namespaces().SetNamespaceMessageTTL(namespace.String(), 0)
+	assert.NoError(t, err)
+
+	// Verify returns 0
+	ttl, err = admin.Namespaces().GetNamespaceMessageTTL(namespace.String())
+	assert.NoError(t, err)
+	assert.Equal(t, 0, ttl)
+
+	// Set to positive value
+	err = admin.Namespaces().SetNamespaceMessageTTL(namespace.String(), 3600)
+	assert.NoError(t, err)
+
+	// Verify returns value
+	ttl, err = admin.Namespaces().GetNamespaceMessageTTL(namespace.String())
+	assert.NoError(t, err)
+	assert.Equal(t, 3600, ttl)
+}
+
+func TestNamespaces_OffloadDeleteLag(t *testing.T) {
+	config := &config.Config{}
+	admin, err := New(config)
+	require.NoError(t, err)
+	require.NotNil(t, admin)
+
+	namespace, _ := utils.GetNamespaceName("public/default")
+
+	// Get default (should be -1)
+	lag, err := admin.Namespaces().GetOffloadDeleteLag(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, int64(-1), lag)
+
+	// Set to 0 explicitly
+	err = admin.Namespaces().SetOffloadDeleteLag(*namespace, 0)
+	assert.NoError(t, err)
+
+	// Verify returns 0
+	lag, err = admin.Namespaces().GetOffloadDeleteLag(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, int64(0), lag)
+
+	// Set to positive value
+	err = admin.Namespaces().SetOffloadDeleteLag(*namespace, 1000)
+	assert.NoError(t, err)
+
+	// Verify returns value
+	lag, err = admin.Namespaces().GetOffloadDeleteLag(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, int64(1000), lag)
+}
+
+func TestNamespaces_MaxConsumersPerTopic(t *testing.T) {
+	config := &config.Config{}
+	admin, err := New(config)
+	require.NoError(t, err)
+	require.NotNil(t, admin)
+
+	namespace, _ := utils.GetNamespaceName("public/default")
+
+	// Get default (should be -1)
+	maxConsumers, err := admin.Namespaces().GetMaxConsumersPerTopic(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, -1, maxConsumers)
+
+	// Set to 0 explicitly
+	err = admin.Namespaces().SetMaxConsumersPerTopic(*namespace, 0)
+	assert.NoError(t, err)
+
+	// Verify returns 0
+	maxConsumers, err = admin.Namespaces().GetMaxConsumersPerTopic(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, 0, maxConsumers)
+
+	// Set to positive value
+	err = admin.Namespaces().SetMaxConsumersPerTopic(*namespace, 100)
+	assert.NoError(t, err)
+
+	// Verify returns value
+	maxConsumers, err = admin.Namespaces().GetMaxConsumersPerTopic(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, 100, maxConsumers)
+}
+
+func TestNamespaces_CompactionThreshold(t *testing.T) {
+	config := &config.Config{}
+	admin, err := New(config)
+	require.NoError(t, err)
+	require.NotNil(t, admin)
+
+	namespace, _ := utils.GetNamespaceName("public/default")
+
+	// Get default (should be -1)
+	threshold, err := admin.Namespaces().GetCompactionThreshold(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, int64(-1), threshold)
+
+	// Set to 0 explicitly
+	err = admin.Namespaces().SetCompactionThreshold(*namespace, 0)
+	assert.NoError(t, err)
+
+	// Verify returns 0
+	threshold, err = admin.Namespaces().GetCompactionThreshold(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, int64(0), threshold)
+
+	// Set to positive value
+	err = admin.Namespaces().SetCompactionThreshold(*namespace, 1024*1024) // 1MB
+	assert.NoError(t, err)
+
+	// Verify returns value
+	threshold, err = admin.Namespaces().GetCompactionThreshold(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, int64(1024*1024), threshold)
+}
+
+func TestNamespaces_MaxProducersPerTopic(t *testing.T) {
+	config := &config.Config{}
+	admin, err := New(config)
+	require.NoError(t, err)
+	require.NotNil(t, admin)
+
+	namespace, _ := utils.GetNamespaceName("public/default")
+
+	// Get default (should be -1)
+	maxProducers, err := admin.Namespaces().GetMaxProducersPerTopic(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, -1, maxProducers)
+
+	// Set to 0 explicitly
+	err = admin.Namespaces().SetMaxProducersPerTopic(*namespace, 0)
+	assert.NoError(t, err)
+
+	// Verify returns 0
+	maxProducers, err = admin.Namespaces().GetMaxProducersPerTopic(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, 0, maxProducers)
+
+	// Set to positive value
+	err = admin.Namespaces().SetMaxProducersPerTopic(*namespace, 50)
+	assert.NoError(t, err)
+
+	// Verify returns value
+	maxProducers, err = admin.Namespaces().GetMaxProducersPerTopic(*namespace)
+	assert.NoError(t, err)
+	assert.Equal(t, 50, maxProducers)
+}
+
+func TestNamespaces_Retention(t *testing.T) {
+	config := &config.Config{}
+	admin, err := New(config)
+	require.NoError(t, err)
+	require.NotNil(t, admin)
+
+	namespaceName := "public/default"
+
+	// Initial state: policy not configured, should return nil
+	retention, err := admin.Namespaces().GetRetention(namespaceName)
+	assert.NoError(t, err)
+	assert.Nil(t, retention, "Expected nil when retention is not configured")
+
+	// Set new retention policy
+	newRetention := utils.RetentionPolicies{
+		RetentionSizeInMB:      1024,
+		RetentionTimeInMinutes: 60,
+	}
+	err = admin.Namespaces().SetRetention(namespaceName, newRetention)
+	assert.NoError(t, err)
+
+	// Verify retention is set
+	retention, err = admin.Namespaces().GetRetention(namespaceName)
+	assert.NoError(t, err)
+	assert.NotNil(t, retention, "Expected non-nil when retention is configured")
+	assert.Equal(t, int64(1024), retention.RetentionSizeInMB)
+	assert.Equal(t, 60, retention.RetentionTimeInMinutes)
+}
+
+func TestNamespaces_BookieAffinityGroup(t *testing.T) {
+	readFile, err := os.ReadFile("../../../integration-tests/tokens/admin-token")
+	require.NoError(t, err)
+
+	config := &config.Config{
+		Token: string(readFile),
+	}
+	admin, err := New(config)
+	require.NoError(t, err)
+	require.NotNil(t, admin)
+
+	namespaceName := "public/default"
+
+	// Initial state: policy not configured, should return nil
+	bookieAffinity, err := admin.Namespaces().GetBookieAffinityGroup(namespaceName)
+	assert.NoError(t, err)
+	assert.Nil(t, bookieAffinity, "Expected nil when bookie affinity group is not configured")
+
+	// Set new bookie affinity group
+	newBookieAffinity := utils.BookieAffinityGroupData{
+		BookkeeperAffinityGroupPrimary:   "primary-group",
+		BookkeeperAffinityGroupSecondary: "secondary-group",
+	}
+	err = admin.Namespaces().SetBookieAffinityGroup(namespaceName, newBookieAffinity)
+	assert.NoError(t, err)
+
+	// Verify bookie affinity group is set
+	bookieAffinity, err = admin.Namespaces().GetBookieAffinityGroup(namespaceName)
+	assert.NoError(t, err)
+	assert.NotNil(t, bookieAffinity, "Expected non-nil when bookie affinity group is configured")
+	assert.Equal(t, "primary-group", bookieAffinity.BookkeeperAffinityGroupPrimary)
+	assert.Equal(t, "secondary-group", bookieAffinity.BookkeeperAffinityGroupSecondary)
+
+	// Remove bookie affinity group - should return nil
+	err = admin.Namespaces().DeleteBookieAffinityGroup(namespaceName)
+	assert.NoError(t, err)
+	bookieAffinity, err = admin.Namespaces().GetBookieAffinityGroup(namespaceName)
+	assert.NoError(t, err)
+	assert.Nil(t, bookieAffinity, "Expected nil after removing bookie affinity group")
+}
+
+func TestNamespaces_Persistence(t *testing.T) {
+	config := &config.Config{}
+	admin, err := New(config)
+	require.NoError(t, err)
+	require.NotNil(t, admin)
+
+	namespaceName := "public/default"
+
+	// Initial state: policy not configured, should return nil
+	persistence, err := admin.Namespaces().GetPersistence(namespaceName)
+	assert.NoError(t, err)
+	assert.Nil(t, persistence, "Expected nil when persistence is not configured")
+
+	// Set new persistence policy
+	newPersistence := utils.PersistencePolicies{
+		BookkeeperEnsemble:             1,
+		BookkeeperWriteQuorum:          1,
+		BookkeeperAckQuorum:            1,
+		ManagedLedgerMaxMarkDeleteRate: 10.0,
+	}
+	err = admin.Namespaces().SetPersistence(namespaceName, newPersistence)
+	assert.NoError(t, err)
+
+	// Verify persistence is set
+	persistence, err = admin.Namespaces().GetPersistence(namespaceName)
+	assert.NoError(t, err)
+	assert.NotNil(t, persistence, "Expected non-nil when persistence is configured")
+	assert.Equal(t, 1, persistence.BookkeeperEnsemble)
+	assert.Equal(t, 1, persistence.BookkeeperWriteQuorum)
+}
