@@ -477,7 +477,7 @@ func TestMessageTTL(t *testing.T) {
 
 	messageTTL, err := admin.Topics().GetMessageTTL(*topicName)
 	assert.NoError(t, err)
-	assert.Equal(t, 0, messageTTL)
+	assert.Equal(t, -1, messageTTL)
 	err = admin.Topics().SetMessageTTL(*topicName, 600)
 	assert.NoError(t, err)
 	//	topic policy is an async operation,
@@ -497,7 +497,7 @@ func TestMessageTTL(t *testing.T) {
 		t,
 		func() bool {
 			messageTTL, err = admin.Topics().GetMessageTTL(*topicName)
-			return err == nil && messageTTL == 0
+			return err == nil && messageTTL == -1
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -516,10 +516,10 @@ func TestRetention(t *testing.T) {
 	err = admin.Topics().Create(*topicName, 4)
 	assert.NoError(t, err)
 
+	// Initial state: policy not configured, should return nil
 	topicRetentionPolicy, err := admin.Topics().GetRetention(*topicName, false)
 	assert.NoError(t, err)
-	assert.Equal(t, int64(0), topicRetentionPolicy.RetentionSizeInMB)
-	assert.Equal(t, 0, topicRetentionPolicy.RetentionTimeInMinutes)
+	assert.Nil(t, topicRetentionPolicy, "Expected nil when retention policy is not configured")
 	err = admin.Topics().SetRetention(*topicName, utils.RetentionPolicies{
 		RetentionSizeInMB:      20480,
 		RetentionTimeInMinutes: 1440,
@@ -540,13 +540,12 @@ func TestRetention(t *testing.T) {
 	)
 	err = admin.Topics().RemoveRetention(*topicName)
 	assert.NoError(t, err)
+	// After removal, should return nil (not configured)
 	assert.Eventually(
 		t,
 		func() bool {
 			topicRetentionPolicy, err = admin.Topics().GetRetention(*topicName, false)
-			return err == nil &&
-				topicRetentionPolicy.RetentionSizeInMB == int64(0) &&
-				topicRetentionPolicy.RetentionTimeInMinutes == 0
+			return err == nil && topicRetentionPolicy == nil
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -565,12 +564,10 @@ func TestSubscribeRate(t *testing.T) {
 	err = admin.Topics().Create(*topicName, 4)
 	assert.NoError(t, err)
 
-	// Get default subscribe rate (adapt to actual server behavior)
+	// Initial state: policy not configured, should return nil
 	initialSubscribeRate, err := admin.Topics().GetSubscribeRate(*topicName)
 	assert.NoError(t, err)
-	// Store initial values for later comparison instead of assuming specific defaults
-	initialConsumerRate := initialSubscribeRate.SubscribeThrottlingRatePerConsumer
-	initialRatePeriod := initialSubscribeRate.RatePeriodInSecond
+	assert.Nil(t, initialSubscribeRate, "Expected nil when subscribe rate is not configured")
 
 	// Set new subscribe rate
 	newSubscribeRate := utils.SubscribeRate{
@@ -594,16 +591,14 @@ func TestSubscribeRate(t *testing.T) {
 		100*time.Millisecond,
 	)
 
-	// Remove subscribe rate policy
+	// Remove subscribe rate policy - should return nil
 	err = admin.Topics().RemoveSubscribeRate(*topicName)
 	assert.NoError(t, err)
 	assert.Eventually(
 		t,
 		func() bool {
 			subscribeRate, err := admin.Topics().GetSubscribeRate(*topicName)
-			return err == nil &&
-				subscribeRate.SubscribeThrottlingRatePerConsumer == initialConsumerRate &&
-				subscribeRate.RatePeriodInSecond == initialRatePeriod
+			return err == nil && subscribeRate == nil
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -622,14 +617,10 @@ func TestSubscriptionDispatchRate(t *testing.T) {
 	err = admin.Topics().Create(*topicName, 4)
 	assert.NoError(t, err)
 
-	// Get default subscription dispatch rate (adapt to actual server behavior)
+	// Initial state: policy not configured, should return nil
 	initialDispatchRate, err := admin.Topics().GetSubscriptionDispatchRate(*topicName)
 	assert.NoError(t, err)
-	// Store initial values for later comparison instead of assuming specific defaults
-	initialMsgRate := initialDispatchRate.DispatchThrottlingRateInMsg
-	initialByteRate := initialDispatchRate.DispatchThrottlingRateInByte
-	initialRatePeriod := initialDispatchRate.RatePeriodInSecond
-	initialRelativeToPublish := initialDispatchRate.RelativeToPublishRate
+	assert.Nil(t, initialDispatchRate, "Expected nil when subscription dispatch rate is not configured")
 
 	// Set new subscription dispatch rate
 	newDispatchRate := utils.DispatchRateData{
@@ -657,18 +648,14 @@ func TestSubscriptionDispatchRate(t *testing.T) {
 		100*time.Millisecond,
 	)
 
-	// Remove subscription dispatch rate policy
+	// Remove subscription dispatch rate policy - should return nil
 	err = admin.Topics().RemoveSubscriptionDispatchRate(*topicName)
 	assert.NoError(t, err)
 	assert.Eventually(
 		t,
 		func() bool {
 			dispatchRate, err := admin.Topics().GetSubscriptionDispatchRate(*topicName)
-			return err == nil &&
-				dispatchRate.DispatchThrottlingRateInMsg == initialMsgRate &&
-				dispatchRate.DispatchThrottlingRateInByte == initialByteRate &&
-				dispatchRate.RatePeriodInSecond == initialRatePeriod &&
-				dispatchRate.RelativeToPublishRate == initialRelativeToPublish
+			return err == nil && dispatchRate == nil
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -690,7 +677,7 @@ func TestMaxConsumersPerSubscription(t *testing.T) {
 	// Get default max consumers per subscription
 	maxConsumers, err := admin.Topics().GetMaxConsumersPerSubscription(*topicName)
 	assert.NoError(t, err)
-	assert.Equal(t, 0, maxConsumers)
+	assert.Equal(t, -1, maxConsumers)
 
 	// Set new max consumers per subscription
 	err = admin.Topics().SetMaxConsumersPerSubscription(*topicName, 10)
@@ -715,7 +702,7 @@ func TestMaxConsumersPerSubscription(t *testing.T) {
 		t,
 		func() bool {
 			maxConsumers, err = admin.Topics().GetMaxConsumersPerSubscription(*topicName)
-			return err == nil && maxConsumers == 0
+			return err == nil && maxConsumers == -1
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -737,7 +724,7 @@ func TestMaxMessageSize(t *testing.T) {
 	// Get default max message size
 	maxMessageSize, err := admin.Topics().GetMaxMessageSize(*topicName)
 	assert.NoError(t, err)
-	assert.Equal(t, 0, maxMessageSize)
+	assert.Equal(t, -1, maxMessageSize)
 
 	// Set new max message size (1MB)
 	err = admin.Topics().SetMaxMessageSize(*topicName, 1048576)
@@ -762,7 +749,7 @@ func TestMaxMessageSize(t *testing.T) {
 		t,
 		func() bool {
 			maxMessageSize, err = admin.Topics().GetMaxMessageSize(*topicName)
-			return err == nil && maxMessageSize == 0
+			return err == nil && maxMessageSize == -1
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -784,7 +771,7 @@ func TestMaxSubscriptionsPerTopic(t *testing.T) {
 	// Get default max subscriptions per topic
 	maxSubscriptions, err := admin.Topics().GetMaxSubscriptionsPerTopic(*topicName)
 	assert.NoError(t, err)
-	assert.Equal(t, 0, maxSubscriptions)
+	assert.Equal(t, -1, maxSubscriptions)
 
 	// Set new max subscriptions per topic
 	err = admin.Topics().SetMaxSubscriptionsPerTopic(*topicName, 100)
@@ -809,7 +796,7 @@ func TestMaxSubscriptionsPerTopic(t *testing.T) {
 		t,
 		func() bool {
 			maxSubscriptions, err = admin.Topics().GetMaxSubscriptionsPerTopic(*topicName)
-			return err == nil && maxSubscriptions == 0
+			return err == nil && maxSubscriptions == -1
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -899,7 +886,7 @@ func TestDeduplicationSnapshotInterval(t *testing.T) {
 	// Get default deduplication snapshot interval
 	interval, err := admin.Topics().GetDeduplicationSnapshotInterval(*topicName)
 	assert.NoError(t, err)
-	assert.Equal(t, 0, interval)
+	assert.Equal(t, -1, interval)
 
 	// Set new deduplication snapshot interval
 	err = admin.Topics().SetDeduplicationSnapshotInterval(*topicName, 1000)
@@ -924,7 +911,7 @@ func TestDeduplicationSnapshotInterval(t *testing.T) {
 		t,
 		func() bool {
 			interval, err = admin.Topics().GetDeduplicationSnapshotInterval(*topicName)
-			return err == nil && interval == 0
+			return err == nil && interval == -1
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -943,14 +930,10 @@ func TestReplicatorDispatchRate(t *testing.T) {
 	err = admin.Topics().Create(*topicName, 4)
 	assert.NoError(t, err)
 
-	// Get default replicator dispatch rate (adapt to actual server behavior)
+	// Initial state: policy not configured, should return nil
 	initialDispatchRate, err := admin.Topics().GetReplicatorDispatchRate(*topicName)
 	assert.NoError(t, err)
-	// Store initial values for later comparison instead of assuming specific defaults
-	initialMsgRate := initialDispatchRate.DispatchThrottlingRateInMsg
-	initialByteRate := initialDispatchRate.DispatchThrottlingRateInByte
-	initialRatePeriod := initialDispatchRate.RatePeriodInSecond
-	initialRelativeToPublish := initialDispatchRate.RelativeToPublishRate
+	assert.Nil(t, initialDispatchRate, "Expected nil when replicator dispatch rate is not configured")
 
 	// Set new replicator dispatch rate
 	newDispatchRate := utils.DispatchRateData{
@@ -978,18 +961,14 @@ func TestReplicatorDispatchRate(t *testing.T) {
 		100*time.Millisecond,
 	)
 
-	// Remove replicator dispatch rate policy
+	// Remove replicator dispatch rate policy - should return nil
 	err = admin.Topics().RemoveReplicatorDispatchRate(*topicName)
 	assert.NoError(t, err)
 	assert.Eventually(
 		t,
 		func() bool {
 			dispatchRate, err := admin.Topics().GetReplicatorDispatchRate(*topicName)
-			return err == nil &&
-				dispatchRate.DispatchThrottlingRateInMsg == initialMsgRate &&
-				dispatchRate.DispatchThrottlingRateInByte == initialByteRate &&
-				dispatchRate.RatePeriodInSecond == initialRatePeriod &&
-				dispatchRate.RelativeToPublishRate == initialRelativeToPublish
+			return err == nil && dispatchRate == nil
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -1008,12 +987,10 @@ func TestOffloadPolicies(t *testing.T) {
 	err = admin.Topics().Create(*topicName, 4)
 	assert.NoError(t, err)
 
-	// Get default offload policies
+	// Initial state: policy not configured, should return nil
 	offloadPolicies, err := admin.Topics().GetOffloadPolicies(*topicName)
 	assert.NoError(t, err)
-	// Default values should be empty/default
-	assert.Equal(t, "", offloadPolicies.ManagedLedgerOffloadDriver)
-	assert.Equal(t, 0, offloadPolicies.ManagedLedgerOffloadMaxThreads)
+	assert.Nil(t, offloadPolicies, "Expected nil when offload policies are not configured")
 
 	// Set new offload policies
 	newOffloadPolicies := utils.OffloadPolicies{
@@ -1045,16 +1022,14 @@ func TestOffloadPolicies(t *testing.T) {
 		100*time.Millisecond,
 	)
 
-	// Remove offload policies
+	// Remove offload policies - should return nil
 	err = admin.Topics().RemoveOffloadPolicies(*topicName)
 	assert.NoError(t, err)
 	assert.Eventually(
 		t,
 		func() bool {
 			offloadPolicies, err = admin.Topics().GetOffloadPolicies(*topicName)
-			return err == nil &&
-				offloadPolicies.ManagedLedgerOffloadDriver == "" &&
-				offloadPolicies.ManagedLedgerOffloadMaxThreads == 0
+			return err == nil && offloadPolicies == nil
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -1073,10 +1048,10 @@ func TestAutoSubscriptionCreation(t *testing.T) {
 	err = admin.Topics().Create(*topicName, 4)
 	assert.NoError(t, err)
 
-	// Get default auto subscription creation
+	// Initial state: policy not configured, should return nil
 	autoSubCreation, err := admin.Topics().GetAutoSubscriptionCreation(*topicName)
 	assert.NoError(t, err)
-	assert.Equal(t, false, autoSubCreation.AllowAutoSubscriptionCreation)
+	assert.Nil(t, autoSubCreation, "Expected nil when auto subscription creation is not configured")
 
 	// Set auto subscription creation to true
 	newAutoSubCreation := utils.AutoSubscriptionCreationOverride{
@@ -1098,15 +1073,14 @@ func TestAutoSubscriptionCreation(t *testing.T) {
 		100*time.Millisecond,
 	)
 
-	// Remove auto subscription creation policy
+	// Remove auto subscription creation policy - should return nil
 	err = admin.Topics().RemoveAutoSubscriptionCreation(*topicName)
 	assert.NoError(t, err)
 	assert.Eventually(
 		t,
 		func() bool {
 			autoSubCreation, err = admin.Topics().GetAutoSubscriptionCreation(*topicName)
-			return err == nil &&
-				autoSubCreation.AllowAutoSubscriptionCreation == false
+			return err == nil && autoSubCreation == nil
 		},
 		10*time.Second,
 		100*time.Millisecond,
@@ -1161,3 +1135,422 @@ func TestSchemaCompatibilityStrategy(t *testing.T) {
 		100*time.Millisecond,
 	)
 }
+
+func TestTopics_MaxProducers(t *testing.T) {
+	randomName := newTopicName()
+	topic := "persistent://public/default/" + randomName
+	cfg := &config.Config{}
+	admin, err := New(cfg)
+	assert.NoError(t, err)
+	assert.NotNil(t, admin)
+	topicName, err := utils.GetTopicName(topic)
+	assert.NoError(t, err)
+	err = admin.Topics().Create(*topicName, 4)
+	assert.NoError(t, err)
+
+	// Get default (should be -1)
+	maxProducers, err := admin.Topics().GetMaxProducers(*topicName)
+	assert.NoError(t, err)
+	assert.Equal(t, -1, maxProducers)
+
+	// Set to 0 explicitly (unlimited)
+	err = admin.Topics().SetMaxProducers(*topicName, 0)
+	assert.NoError(t, err)
+
+	// Verify returns 0
+	assert.Eventually(
+		t,
+		func() bool {
+			maxProducers, err = admin.Topics().GetMaxProducers(*topicName)
+			return err == nil && maxProducers == 0
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Set to positive value
+	err = admin.Topics().SetMaxProducers(*topicName, 10)
+	assert.NoError(t, err)
+
+	// Verify returns value
+	assert.Eventually(
+		t,
+		func() bool {
+			maxProducers, err = admin.Topics().GetMaxProducers(*topicName)
+			return err == nil && maxProducers == 10
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Remove
+	err = admin.Topics().RemoveMaxProducers(*topicName)
+	assert.NoError(t, err)
+}
+
+func TestTopics_MaxConsumers(t *testing.T) {
+	randomName := newTopicName()
+	topic := "persistent://public/default/" + randomName
+	cfg := &config.Config{}
+	admin, err := New(cfg)
+	assert.NoError(t, err)
+	assert.NotNil(t, admin)
+	topicName, err := utils.GetTopicName(topic)
+	assert.NoError(t, err)
+	err = admin.Topics().Create(*topicName, 4)
+	assert.NoError(t, err)
+
+	// Get default (should be -1)
+	maxConsumers, err := admin.Topics().GetMaxConsumers(*topicName)
+	assert.NoError(t, err)
+	assert.Equal(t, -1, maxConsumers)
+
+	// Set to 0 explicitly
+	err = admin.Topics().SetMaxConsumers(*topicName, 0)
+	assert.NoError(t, err)
+
+	// Verify returns 0
+	assert.Eventually(
+		t,
+		func() bool {
+			maxConsumers, err = admin.Topics().GetMaxConsumers(*topicName)
+			return err == nil && maxConsumers == 0
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Set to positive value
+	err = admin.Topics().SetMaxConsumers(*topicName, 20)
+	assert.NoError(t, err)
+
+	// Verify returns value
+	assert.Eventually(
+		t,
+		func() bool {
+			maxConsumers, err = admin.Topics().GetMaxConsumers(*topicName)
+			return err == nil && maxConsumers == 20
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Remove
+	err = admin.Topics().RemoveMaxConsumers(*topicName)
+	assert.NoError(t, err)
+}
+
+func TestTopics_MaxUnackMessagesPerConsumer(t *testing.T) {
+	randomName := newTopicName()
+	topic := "persistent://public/default/" + randomName
+	cfg := &config.Config{}
+	admin, err := New(cfg)
+	assert.NoError(t, err)
+	assert.NotNil(t, admin)
+	topicName, err := utils.GetTopicName(topic)
+	assert.NoError(t, err)
+	err = admin.Topics().Create(*topicName, 4)
+	assert.NoError(t, err)
+
+	// Get default (should be -1)
+	maxUnack, err := admin.Topics().GetMaxUnackMessagesPerConsumer(*topicName)
+	assert.NoError(t, err)
+	assert.Equal(t, -1, maxUnack)
+
+	// Set to 0 explicitly
+	err = admin.Topics().SetMaxUnackMessagesPerConsumer(*topicName, 0)
+	assert.NoError(t, err)
+
+	// Verify returns 0
+	assert.Eventually(
+		t,
+		func() bool {
+			maxUnack, err = admin.Topics().GetMaxUnackMessagesPerConsumer(*topicName)
+			return err == nil && maxUnack == 0
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Set to positive value
+	err = admin.Topics().SetMaxUnackMessagesPerConsumer(*topicName, 1000)
+	assert.NoError(t, err)
+
+	// Verify returns value
+	assert.Eventually(
+		t,
+		func() bool {
+			maxUnack, err = admin.Topics().GetMaxUnackMessagesPerConsumer(*topicName)
+			return err == nil && maxUnack == 1000
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Remove
+	err = admin.Topics().RemoveMaxUnackMessagesPerConsumer(*topicName)
+	assert.NoError(t, err)
+}
+
+func TestTopics_MaxUnackMessagesPerSubscription(t *testing.T) {
+	randomName := newTopicName()
+	topic := "persistent://public/default/" + randomName
+	cfg := &config.Config{}
+	admin, err := New(cfg)
+	assert.NoError(t, err)
+	assert.NotNil(t, admin)
+	topicName, err := utils.GetTopicName(topic)
+	assert.NoError(t, err)
+	err = admin.Topics().Create(*topicName, 4)
+	assert.NoError(t, err)
+
+	// Get default (should be -1)
+	maxUnack, err := admin.Topics().GetMaxUnackMessagesPerSubscription(*topicName)
+	assert.NoError(t, err)
+	assert.Equal(t, -1, maxUnack)
+
+	// Set to 0 explicitly
+	err = admin.Topics().SetMaxUnackMessagesPerSubscription(*topicName, 0)
+	assert.NoError(t, err)
+
+	// Verify returns 0
+	assert.Eventually(
+		t,
+		func() bool {
+			maxUnack, err = admin.Topics().GetMaxUnackMessagesPerSubscription(*topicName)
+			return err == nil && maxUnack == 0
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Set to positive value
+	err = admin.Topics().SetMaxUnackMessagesPerSubscription(*topicName, 5000)
+	assert.NoError(t, err)
+
+	// Verify returns value
+	assert.Eventually(
+		t,
+		func() bool {
+			maxUnack, err = admin.Topics().GetMaxUnackMessagesPerSubscription(*topicName)
+			return err == nil && maxUnack == 5000
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Remove
+	err = admin.Topics().RemoveMaxUnackMessagesPerSubscription(*topicName)
+	assert.NoError(t, err)
+}
+
+func TestTopics_Persistence(t *testing.T) {
+	randomName := newTopicName()
+	topic := "persistent://public/default/" + randomName
+	cfg := &config.Config{}
+	admin, err := New(cfg)
+	assert.NoError(t, err)
+	assert.NotNil(t, admin)
+	topicName, err := utils.GetTopicName(topic)
+	assert.NoError(t, err)
+	err = admin.Topics().Create(*topicName, 4)
+	assert.NoError(t, err)
+
+	// Initial state: policy not configured, should return nil
+	persistence, err := admin.Topics().GetPersistence(*topicName)
+	assert.NoError(t, err)
+	assert.Nil(t, persistence, "Expected nil when persistence is not configured")
+
+	// Set new persistence policy
+	newPersistence := utils.PersistenceData{
+		BookkeeperEnsemble:             1,
+		BookkeeperWriteQuorum:          1,
+		BookkeeperAckQuorum:            1,
+		ManagedLedgerMaxMarkDeleteRate: 10.0,
+	}
+	err = admin.Topics().SetPersistence(*topicName, newPersistence)
+	assert.NoError(t, err)
+
+	// Verify persistence is set
+	assert.Eventually(
+		t,
+		func() bool {
+			persistence, err = admin.Topics().GetPersistence(*topicName)
+			return err == nil && persistence != nil &&
+				persistence.BookkeeperEnsemble == 1 &&
+				persistence.BookkeeperWriteQuorum == 1
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Remove persistence policy - should return nil
+	err = admin.Topics().RemovePersistence(*topicName)
+	assert.NoError(t, err)
+	assert.Eventually(
+		t,
+		func() bool {
+			persistence, err = admin.Topics().GetPersistence(*topicName)
+			return err == nil && persistence == nil
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+}
+
+func TestTopics_DelayedDelivery(t *testing.T) {
+	randomName := newTopicName()
+	topic := "persistent://public/default/" + randomName
+	cfg := &config.Config{}
+	admin, err := New(cfg)
+	assert.NoError(t, err)
+	assert.NotNil(t, admin)
+	topicName, err := utils.GetTopicName(topic)
+	assert.NoError(t, err)
+	err = admin.Topics().Create(*topicName, 4)
+	assert.NoError(t, err)
+
+	// Initial state: policy not configured, should return nil
+	delayedDelivery, err := admin.Topics().GetDelayedDelivery(*topicName)
+	assert.NoError(t, err)
+	assert.Nil(t, delayedDelivery, "Expected nil when delayed delivery is not configured")
+
+	// Set new delayed delivery policy
+	newDelayedDelivery := utils.DelayedDeliveryData{
+		Active:           true,
+		TickTime:         1000,
+		MaxDelayInMillis: 60000,
+	}
+	err = admin.Topics().SetDelayedDelivery(*topicName, newDelayedDelivery)
+	assert.NoError(t, err)
+
+	// Verify delayed delivery is set
+	assert.Eventually(
+		t,
+		func() bool {
+			delayedDelivery, err = admin.Topics().GetDelayedDelivery(*topicName)
+			return err == nil && delayedDelivery != nil &&
+				delayedDelivery.Active == true &&
+				delayedDelivery.TickTime == 1000
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Remove delayed delivery policy - should return nil
+	err = admin.Topics().RemoveDelayedDelivery(*topicName)
+	assert.NoError(t, err)
+	assert.Eventually(
+		t,
+		func() bool {
+			delayedDelivery, err = admin.Topics().GetDelayedDelivery(*topicName)
+			return err == nil && delayedDelivery == nil
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+}
+
+func TestTopics_DispatchRate(t *testing.T) {
+	randomName := newTopicName()
+	topic := "persistent://public/default/" + randomName
+	cfg := &config.Config{}
+	admin, err := New(cfg)
+	assert.NoError(t, err)
+	assert.NotNil(t, admin)
+	topicName, err := utils.GetTopicName(topic)
+	assert.NoError(t, err)
+	err = admin.Topics().Create(*topicName, 4)
+	assert.NoError(t, err)
+
+	// Initial state: policy not configured, should return nil
+	dispatchRate, err := admin.Topics().GetDispatchRate(*topicName)
+	assert.NoError(t, err)
+	assert.Nil(t, dispatchRate, "Expected nil when dispatch rate is not configured")
+
+	// Set new dispatch rate
+	newDispatchRate := utils.DispatchRateData{
+		DispatchThrottlingRateInMsg:  100,
+		DispatchThrottlingRateInByte: 1048576,
+		RatePeriodInSecond:           60,
+		RelativeToPublishRate:        false,
+	}
+	err = admin.Topics().SetDispatchRate(*topicName, newDispatchRate)
+	assert.NoError(t, err)
+
+	// Verify dispatch rate is set
+	assert.Eventually(
+		t,
+		func() bool {
+			dispatchRate, err = admin.Topics().GetDispatchRate(*topicName)
+			return err == nil && dispatchRate != nil &&
+				dispatchRate.DispatchThrottlingRateInMsg == 100
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Remove dispatch rate policy - should return nil
+	err = admin.Topics().RemoveDispatchRate(*topicName)
+	assert.NoError(t, err)
+	assert.Eventually(
+		t,
+		func() bool {
+			dispatchRate, err = admin.Topics().GetDispatchRate(*topicName)
+			return err == nil && dispatchRate == nil
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+}
+
+func TestTopics_PublishRate(t *testing.T) {
+	randomName := newTopicName()
+	topic := "persistent://public/default/" + randomName
+	cfg := &config.Config{}
+	admin, err := New(cfg)
+	assert.NoError(t, err)
+	assert.NotNil(t, admin)
+	topicName, err := utils.GetTopicName(topic)
+	assert.NoError(t, err)
+	err = admin.Topics().Create(*topicName, 4)
+	assert.NoError(t, err)
+
+	// Initial state: policy not configured, should return nil
+	publishRate, err := admin.Topics().GetPublishRate(*topicName)
+	assert.NoError(t, err)
+	assert.Nil(t, publishRate, "Expected nil when publish rate is not configured")
+
+	// Set new publish rate
+	newPublishRate := utils.PublishRateData{
+		PublishThrottlingRateInMsg:  200,
+		PublishThrottlingRateInByte: 2097152,
+	}
+	err = admin.Topics().SetPublishRate(*topicName, newPublishRate)
+	assert.NoError(t, err)
+
+	// Verify publish rate is set
+	assert.Eventually(
+		t,
+		func() bool {
+			publishRate, err = admin.Topics().GetPublishRate(*topicName)
+			return err == nil && publishRate != nil &&
+				publishRate.PublishThrottlingRateInMsg == 200
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+
+	// Remove publish rate policy - should return nil
+	err = admin.Topics().RemovePublishRate(*topicName)
+	assert.NoError(t, err)
+	assert.Eventually(
+		t,
+		func() bool {
+			publishRate, err = admin.Topics().GetPublishRate(*topicName)
+			return err == nil && publishRate == nil
+		},
+		10*time.Second,
+		100*time.Millisecond,
+	)
+}
